@@ -11,6 +11,8 @@ import threading  # This module is used to create threads.
 from enum import Enum
 from typing import Iterable as _Iterable, Union as _Union, Callable as _Callable
 
+__all__ = ['Proxy', 'ProxyType', 'ProxyList', 'ProxyStatus']
+
 
 class ProxyStatus(Enum):
     """
@@ -30,6 +32,16 @@ class ProxyType(Enum):
     SOCKS4 = 2
     SOCKS5 = 3
 
+    def __init__(self, type_: _Union[int, str]):
+        super(ProxyType, self).__init__()
+        if isinstance(type_, int):
+            if type_ in [0, 1, 2, 3]:
+                self.value = type_
+            else:
+                raise ValueError(f'Invalid proxy type({type_}).')
+        elif isinstance(type_, str):
+            self.value = ProxyType.from_name(type_).value
+
     @staticmethod
     def from_name(name: str) -> 'ProxyType':
         """
@@ -106,6 +118,7 @@ class Proxy:
         """
         This method is used to create a Proxy from a text.
         :param text: The text to create the Proxy from.
+        :param default_type: The default type of the Proxy.
         :return: The Proxy.
         """
         if text.count(':') == 1:
